@@ -12,13 +12,13 @@ class ServerStateLock(collections.abc.Mapping):
         self._server_state = server_state
 
     def __getitem__(self, k: str) -> threading.RLock:
-        try:
-            item = self._server_state._items[k]
-        except KeyError:
-            raise KeyError(k)
+        item = self._server_state._ensure_item(k)
 
         return item._value_lock
 
+    def __getattr__(self, k: str) -> threading.RLock:
+        return self.__getitem__(k)
+
     def __contains__(self, k: object) -> bool:
         return k in self._server_state._items
 
